==> jc-1.4.0.tar.gz: javax/print/attribute/UnmodifiableSetException.h <==
// public class javax.print.attribute.UnmodifiableSetException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a80f286006ce628f javax_print_attribute_UnmodifiableSetException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_javax_print_attribute_UnmodifiableSetException_H_
#define _JC_javax_print_attribute_UnmodifiableSetException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$sub_refs	_jc_javax_print_attribute_UnmodifiableSetException$sub_refs;
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$sub_nonrefs	_jc_javax_print_attribute_UnmodifiableSetException$sub_nonrefs;
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$refs	_jc_javax_print_attribute_UnmodifiableSetException$refs;
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$nonrefs	_jc_javax_print_attribute_UnmodifiableSetException$nonrefs;
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$object	_jc_javax_print_attribute_UnmodifiableSetException$object;

typedef const struct _jc_javax_print_attribute_UnmodifiableSetException$vmethods	_jc_javax_print_attribute_UnmodifiableSetException$vmethods;
typedef const struct _jc_javax_print_attribute_UnmodifiableSetException$vtable	_jc_javax_print_attribute_UnmodifiableSetException$vtable;
typedef const struct _jc_javax_print_attribute_UnmodifiableSetException$vtype	_jc_javax_print_attribute_UnmodifiableSetException$vtype;

// Constructors
extern void _jc_javax_print_attribute_UnmodifiableSetException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_UnmodifiableSetException$object *);
extern void _jc_javax_print_attribute_UnmodifiableSetException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_attribute_UnmodifiableSetException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_print_attribute_UnmodifiableSetException$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_UnmodifiableSetException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_javax_print_attribute_UnmodifiableSetException$vmethods	javax_print_attribute_UnmodifiableSetException;
};

// Vtype
struct _jc_javax_print_attribute_UnmodifiableSetException$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_UnmodifiableSetException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_UnmodifiableSetException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_UnmodifiableSetException$refs {
    _jc_javax_print_attribute_UnmodifiableSetException$sub_refs	javax_print_attribute_UnmodifiableSetException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_UnmodifiableSetException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_UnmodifiableSetException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_javax_print_attribute_UnmodifiableSetException$sub_nonrefs	javax_print_attribute_UnmodifiableSetException;
};

// Object instance structure
struct _jc_javax_print_attribute_UnmodifiableSetException$object {
	_jc_javax_print_attribute_UnmodifiableSetException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_UnmodifiableSetException$vtype	*vtype;
	_jc_javax_print_attribute_UnmodifiableSetException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_UnmodifiableSetException$vtype _jc_javax_print_attribute_UnmodifiableSetException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_UnmodifiableSetException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_UnmodifiableSetException$class_object;

#endif	/* _JC_javax_print_attribute_UnmodifiableSetException_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/UnmodifiableSetException.h <==
// public class javax.print.attribute.UnmodifiableSetException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a80f286006ce628f javax_print_attribute_UnmodifiableSetException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_javax_print_attribute_UnmodifiableSetException_H_
#define _JC_javax_print_attribute_UnmodifiableSetException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$sub_refs	_jc_javax_print_attribute_UnmodifiableSetException$sub_refs;
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$sub_nonrefs	_jc_javax_print_attribute_UnmodifiableSetException$sub_nonrefs;
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$refs	_jc_javax_print_attribute_UnmodifiableSetException$refs;
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$nonrefs	_jc_javax_print_attribute_UnmodifiableSetException$nonrefs;
typedef struct _jc_javax_print_attribute_UnmodifiableSetException$object	_jc_javax_print_attribute_UnmodifiableSetException$object;

typedef const struct _jc_javax_print_attribute_UnmodifiableSetException$vmethods	_jc_javax_print_attribute_UnmodifiableSetException$vmethods;
typedef const struct _jc_javax_print_attribute_UnmodifiableSetException$vtable	_jc_javax_print_attribute_UnmodifiableSetException$vtable;
typedef const struct _jc_javax_print_attribute_UnmodifiableSetException$vtype	_jc_javax_print_attribute_UnmodifiableSetException$vtype;

// Constructors
extern void _jc_javax_print_attribute_UnmodifiableSetException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_UnmodifiableSetException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_UnmodifiableSetException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_attribute_UnmodifiableSetException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_UnmodifiableSetException$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_UnmodifiableSetException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_javax_print_attribute_UnmodifiableSetException$vmethods	javax_print_attribute_UnmodifiableSetException;
};

// Vtype
struct _jc_javax_print_attribute_UnmodifiableSetException$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_UnmodifiableSetException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_UnmodifiableSetException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_UnmodifiableSetException$refs {
    _jc_javax_print_attribute_UnmodifiableSetException$sub_refs	javax_print_attribute_UnmodifiableSetException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_UnmodifiableSetException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_UnmodifiableSetException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_javax_print_attribute_UnmodifiableSetException$sub_nonrefs	javax_print_attribute_UnmodifiableSetException;
};

// Object instance structure
struct _jc_javax_print_attribute_UnmodifiableSetException$object {
	_jc_javax_print_attribute_UnmodifiableSetException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_UnmodifiableSetException$vtype	*vtype;
	_jc_javax_print_attribute_UnmodifiableSetException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_UnmodifiableSetException$vtype _jc_javax_print_attribute_UnmodifiableSetException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_UnmodifiableSetException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_UnmodifiableSetException$class_object;

#endif	/* _JC_javax_print_attribute_UnmodifiableSetException_H_ */
